@@ -36,8 +36,7 @@
 
 $cgextensions = cms_join_path($gCms->config['root_path'],'modules',
 			      'CGExtensions','CGExtensions.module.php');
-if( !is_readable( $cgextensions ) )
-{
+if( !is_readable( $cgextensions ) ) {
   echo '<h1><font color="red">ERROR: The CGExtensions module could not be found.</font></h1>';
   return;
 }
@@ -87,29 +86,18 @@ function cggm_add_category($params, &$smarty)
     $map = $mod->GetPreference('default_map',0);
   }
 
-  if( !isset($params['name']) ) {
-    // name is required
-    return; 
-  }
+  if( !isset($params['name']) ) return; // name is required
   $name = $params['name'];
-  
+
   $key = $name;
-  if( isset($params['key']) ) {
-    $key = trim($params['name']);
-  }
+  if( isset($params['key']) ) $key = trim($params['name']);
 
   $description = '';
-  if( isset($params['desc']) ) {
-    $description = $params['desc'];
-  }
-  if( isset($params['description']) ) {
-    $description = $params['description'];
-  }
-  
+  if( isset($params['desc']) ) $description = $params['desc'];
+  if( isset($params['description']) ) $description = $params['description'];
+
   $icon = '';
-  if( isset($params['icon']) ) {
-    $icon = $params['icon'];
-  }
+  if( isset($params['icon']) ) $icon = $params['icon'];
 
   $mod = cge_utils::get_module('CGGoogleMaps');
   $obj = new cggm_category($name,$key);
@@ -145,10 +133,7 @@ function cggm_add_dynpoint($params, &$smarty)
     $keys = array($mod->GetPreference('default_map',0));
   }
 
-  if( !isset($params['name']) ) {
-    // name is required
-    return; 
-  }
+  if( !isset($params['name']) ) return; // name is required
   $name = trim($params['name']);
   if( $name == '' ) return;
 
@@ -161,9 +146,7 @@ function cggm_add_dynpoint($params, &$smarty)
   }
   
   $address = '';
-  if( isset($params['address']) && $params['address'] != '' ) {
-    $address = $params['address'];
-  }
+  if( isset($params['address']) && $params['address'] != '' ) $address = $params['address'];
   
   $lat = '';
   if( isset($params['lat']) && $params['lat'] != '' ) {
@@ -182,23 +165,16 @@ function cggm_add_dynpoint($params, &$smarty)
   }
 
   $icon = '';
-  if( isset($params['icon']) && $params['icon'] != '') {
-    $icon = $params['icon'];
-  }
+  if( isset($params['icon']) && $params['icon'] != '') $icon = $params['icon'];
 
   try {
     $obj = new cggm_marker($name,$address,$lat,$long,$icon);
     $obj->set_description($description);
     if( isset($params['category']) && $params['category'] != '' ) {
       $tmp = trim($params['category']);
-      if( $tmp ) {
-	$obj->add_category(trim($tmp));
-      }
+      if( $tmp ) $obj->add_category(trim($tmp));
     }
 
-    if( isset($params['tooltip']) && $params['tooltip'] != '' ) {
-      $obj->set_tooltip($params['tooltip']);
-    }
     foreach( $keys as $onekey ) {
       $mod->add_map_point($onekey,$obj);
     }
@@ -225,10 +201,7 @@ function cggm_add_kml($params, &$smarty)
     $map = $mapobj->id;
   }
 
-  if( !isset($params['href']) ) {
-    // href is required
-    return;
-  }
+  if( !isset($params['href']) ) return; // href is required
   $href = trim($params['href']);
   if( $href == '' ) return;
 
@@ -237,17 +210,17 @@ function cggm_add_kml($params, &$smarty)
 }
 
 /* ---- Begin Class --- */
-class CGGoogleMaps extends CGExtensions
+final class CGGoogleMaps extends CGExtensions
 {
   var $_dynamic_points;
   var $_dyn_categories;
   var $_kml_files;
   var $_dyn_attrs;
+  static $_icons;
 
-  function CGGoogleMaps()
+  function __construct()
   {
-    parent::CMSModule();
-    $this->_dynamic_points = null;
+    parent::__construct();
     $this->AddImageDir('icons');
 
     $gCms = cmsms();
@@ -257,63 +230,26 @@ class CGGoogleMaps extends CGExtensions
     $smarty->register_function('cggm_add_kml','cggm_add_kml');
   }
 
-  function GetName()
-  {
-    return 'CGGoogleMaps';
-  }
-
-  function GetFriendlyName()
-  {
-    return $this->Lang('friendlyname');
-  }
-	
-  function GetVersion()
-  {
-    return '2.4.5';
-  }
-
-  function GetHelp()
-  {
-    return file_get_contents(dirname(__FILE__).'/help.inc');
-  }
-
-  function GetAuthor()
-  {
-    return 'calguy1000';
-  }
-
-  function GetAuthorEmail()
-  {
-    return 'calguy1000@hotmail.com';
-  }
-
-  function GetChangeLog()
-  {
-    return file_get_contents(dirname(__FILE__).'/changelog.inc');
-  }
-  
-  function IsPluginModule()
-  {
-    return true;
-  }
-
-  function HasAdmin()
-  {
-    return true;
-  }
-
-  function GetAdminSection()
-  {
-    return 'extensions';
-  }
-
-  function GetAdminDescription()
-  {
-    return $this->Lang('moddescription');
-  }
-
+  function GetName() { return 'CGGoogleMaps'; }
+  function GetFriendlyName() { return $this->Lang('friendlyname'); }
+  function GetVersion() { return '2.4.6'; }
+  function GetHelp() { return file_get_contents(__DIR__.'/help.inc'); }
+  function GetAuthor() { return 'calguy1000'; }
+  function GetAuthorEmail() { return 'calguy1000@cmsmadesimple.org'; }
+  function GetChangeLog() { return file_get_contents(__DIR__.'/changelog.inc'); }
+  function IsPluginModule() { return true; }
+  function HasAdmin() { return true; }
+  function GetAdminSection() { return 'extensions'; }
+  function GetAdminDescription() { return $this->Lang('moddescription'); }
   function LazyLoadAdmin() { return TRUE; }
   function LazyLoadFrontend() { return FALSE; }
+  function MinimumCMSVersion() { return '1.11.7'; }
+  function InstallPostMessage() { return $this->Lang('postinstall'); }
+  function UninstallPostMessage() { return $this->Lang('postuninstall'); }
+  function UninstallPreMessage() { return $this->Lang('really_uninstall'); }	
+  function AllowAutoInstall() { return FALSE; }
+  function AllowAutoUpgrade() { return FALSE; }
+  function GetDependencies() { return array('CGExtensions'=>'1.36','CGSimpleSmarty'=>'1.6.2'); }
 
   function GetHeaderHTML()
   {
@@ -335,82 +271,72 @@ EOT;
       $this->CheckPermission('Modify Site Preferences');
   }
 
-  function GetDependencies()
+  public function InitializeAdmin()
   {
-    return array('CGExtensions'=>'1.31',
-		 'CGSimpleSmarty'=>'1.4');
+    $this->CreateParameter('map','',$this->Lang('help_param_map'));
+    $this->CreateParameter('key','',$this->Lang('help_param_key'));
+    $this->CreateParameter('defer','0',$this->Lang('help_param_defer'));
+    $this->CreateParameter('maptemplate','',$this->Lang('help_param_maptemplate'));
+    $this->CreateParameter('zoomlevel','',$this->Lang('help_param_zoomlevel'));
+    $this->CreateParameter('zoom_encompass','',$this->Lang('help_param_zoomencompass'));
+    $this->CreateParameter('width','',$this->Lang('help_param_width'));
+    $this->CreateParameter('height','',$this->Lang('help_param_height'));
   }
-
-  function MinimumCMSVersion()
-  {
-    return "1.11.2";
-  }
-	
-  function SetParameters()
+  
+  public function InitializeFrontend()
   {
     $this->RegisterModulePlugin();
     $this->RestrictUnknownParams();
-
-    $this->CreateParameter('map','',$this->Lang('help_param_map'));
     $this->SetParameterType('map',CLEAN_STRING);
-
-    $this->CreateParameter('key','',$this->Lang('help_param_key'));
     $this->SetParameterType('key',CLEAN_STRING);
-    
-    $this->CreateParameter('defer','0',$this->Lang('help_param_defer'));
     $this->SetParameterType('defer',CLEAN_INT);
-
-    $this->CreateParameter('maptemplate','',$this->Lang('help_param_maptemplate'));
     $this->SetParameterType('maptemplate',CLEAN_STRING);
-
-    $this->CreateParameter('zoomlevel','',$this->Lang('help_param_zoomlevel'));
     $this->SetParameterType('zoomlevel',CLEAN_INT);
-
-    $this->CreateParameter('zoom_encompass','',$this->Lang('help_param_zoomencompass'));
     $this->SetParameterType('zoom_encompass',CLEAN_INT);
-
-    $this->CreateParameter('width','',$this->Lang('help_param_width'));
     $this->SetParameterType('width',CLEAN_INT);
-
-    $this->CreateParameter('height','',$this->Lang('help_param_height'));
     $this->SetParameterType('height',CLEAN_INT);
-
     $this->SetParameterType('address',CLEAN_STRING);
   }
 
-  function InstallPostMessage()
+  public function HasCapability($capability,$params = array())
   {
-    return $this->Lang('postinstall');
-  }
-
-  function UninstallPostMessage()
-  {
-    return $this->Lang('postuninstall');
-  }
-
-  function UninstallPreMessage()
-  {
-    return $this->Lang('really_uninstall');
-  }	
-
-  function AllowAutoInstall() {
+    if( strtolower($capability) == 'geolocate' ) return TRUE;
     return FALSE;
+  }  
+
+  public function GetIconsFull()
+  {
+    if( is_array(self::$_icons) ) return self::$_icons;
+
+    $db = cmsms()->GetDb();
+    $query = 'SELECT * FROM '.cms_db_prefix().'module_cggooglemaps_icons ORDER BY name ASC';
+    $data = $db->GetArray($query);
+    self::$_icons = array();
+    if( is_array($data) && count($data) ) self::$_icons = cge_array::to_hash($data,'name');
+    return self::$_icons;
   }
 
-  function AllowAutoUpgrade() {
-    return FALSE;
+  public function GetIconList()
+  {
+    $data = $this->GetIconsFull();
+    $out = null;
+    if( is_array($data) && count($data) ) {
+      foreach( $data as $name => $row ) {
+	$out[$name] = $name;
+      }
+    }
+    return $out;
   }
 
   function GetCoordsFromAddress($address)
   {
     $tmp = cggm_address_lookup::lookup($address);
-    if( is_array($tmp) )
-      {
-	$data = array();
-	$data['lat'] = $tmp[0];
-	$data['lon'] = $tmp[1];
-	return $data;
-      }
+    if( is_array($tmp) ) {
+      $data = array();
+      $data['lat'] = $tmp[0];
+      $data['lon'] = $tmp[1];
+      return $data;
+    }
     return $tmp;
   }
 
@@ -422,71 +348,61 @@ EOT;
   // returns $min_lat,$max_lat,$min_lon,$max_lon 
   function GetBoundingBox($lat_degrees,$lon_degrees,$distance_in_miles) 
   {
-	
     $radius = 3963.1; // of earth in miles
-	
+
     // bearings	
     $due_north = 0;
     $due_south = 180;
     $due_east = 90;
     $due_west = 270;
-	
+
     // convert latitude and longitude into radians 
     $lat_r = deg2rad($lat_degrees);
     $lon_r = deg2rad($lon_degrees);
-			
+
     // find the northmost, southmost, eastmost and westmost corners $distance_in_miles away
     // original formula from
     // http://www.movable-type.co.uk/scripts/latlong.html
-	
+
     $northmost  = asin(sin($lat_r) * cos($distance_in_miles/$radius) + cos($lat_r) * sin ($distance_in_miles/$radius) * cos($due_north));
     $southmost  = asin(sin($lat_r) * cos($distance_in_miles/$radius) + cos($lat_r) * sin ($distance_in_miles/$radius) * cos($due_south));
-		
     $eastmost = $lon_r + atan2(sin($due_east)*sin($distance_in_miles/$radius)*cos($lat_r),cos($distance_in_miles/$radius)-sin($lat_r)*sin($lat_r));
     $westmost = $lon_r + atan2(sin($due_west)*sin($distance_in_miles/$radius)*cos($lat_r),cos($distance_in_miles/$radius)-sin($lat_r)*sin($lat_r));			
-			
     $northmost = rad2deg($northmost);
     $southmost = rad2deg($southmost);
     $eastmost = rad2deg($eastmost);
     $westmost = rad2deg($westmost);
-			
+
     // sort the lat and long so that we can use them for a between query		
     if ($northmost > $southmost) { 
       $lat1 = $southmost;
       $lat2 = $northmost;
-		
     } else {
       $lat1 = $northmost;
       $lat2 = $southmost;
     }
-	
-	
+
     if ($eastmost > $westmost) { 
       $lon1 = $westmost;
       $lon2 = $eastmost;
-		
     } else {
       $lon1 = $eastmost;
       $lon2 = $westmost;
     }
-		
+
     return array($lat1,$lat2,$lon1,$lon2);
   }
 
   function AddDynamicPoint($map,$name,$description,$address='',
-			   $lat='',$long='',$icon='',$tooltip = '',
+			   $lat='',$long='',$icon='',
 			   $sidebar_class = '',$sidebar_html = '')
   {
     if( empty($map) ) return FALSE;
     if( empty($name) ) return FALSE;
     if( empty($address) && (empty($lat) || empty($long)) ) return FALSE;
 
-    if( !is_array($this->_dynamic_points) ) {
-      $this->_dynamic_points = array();
-    }
-    if( !isset($this->_dynamic_points[$map]) ) {
-      $this->_dynamic_points[$map] = array();
-    }
+    if( !is_array($this->_dynamic_points) ) $this->_dynamic_points = array();
+    if( !isset($this->_dynamic_points[$map]) ) $this->_dynamic_points[$map] = array();
 
     // everything is good to go, build the point object.
     $obj = new cggm_marker($name,$address,$lat,$long,$icon);
@@ -496,12 +412,8 @@ EOT;
 
   public function add_map_point($map,cggm_marker& $obj)
   {
-    if( !is_array($this->_dynamic_points) ) {
-      $this->_dynamic_points = array();
-    }
-    if( !isset($this->_dynamic_points[$map]) ) {
-      $this->_dynamic_points[$map] = array();
-    }
+    if( !is_array($this->_dynamic_points) ) $this->_dynamic_points = array();
+    if( !isset($this->_dynamic_points[$map]) ) $this->_dynamic_points[$map] = array();
 
     $this->_dynamic_points[$map][] = $obj;
   }
@@ -509,37 +421,24 @@ EOT;
   public function add_map_category($map,cggm_category& $obj)
   {
     if( $map == '' ) return FALSE;
-    if( !is_array($this->_dyn_categories) ) {
-      $this->_dyn_categories = array();
-    }
-    if( !isset($this->_dyn_categories[$map]) ) {
-      $this->_dyn_categories[$map] = array();
-    }
-
+    if( !is_array($this->_dyn_categories) ) $this->_dyn_categories = array();
+    if( !isset($this->_dyn_categories[$map]) ) $this->_dyn_categories[$map] = array();
     $this->_dyn_categories[$map][] = $obj;
   }
 
   public function add_kml($map,$href)
   {
     $map = (int)$map;
-    if( !is_array($this->_kml_files) ) {
-      $this->_kml_files = array();
-    }
-    if( !isset($this->_kml_files[$map]) ) {
-      $this->_kml_files[$map] = array();
-    }
+    if( !is_array($this->_kml_files) ) $this->_kml_files = array();
+    if( !isset($this->_kml_files[$map]) ) $this->_kml_files[$map] = array();
     $this->_kml_files[$map][] = $href;
   }
 
   public function add_attr($map,$key,$value)
   {
     $map = (int)$map;
-    if( !is_array($this->_dyn_attrs) ) {
-      $this->_dyn_attrs = array();
-    }
-    if( !isset($this->_dyn_attrs[$map]) ) {
-      $this->_dyn_attrs[$map] = array();
-    }
+    if( !is_array($this->_dyn_attrs) ) $this->_dyn_attrs = array();
+    if( !isset($this->_dyn_attrs[$map]) ) $this->_dyn_attrs[$map] = array();
     if( $value !== '' ) {
       $this->_dyn_attrs[$map][$key] = $value;
     }
@@ -549,4 +448,7 @@ EOT;
   }
 } // class
 
+#
+# EOF
+#
 ?>
