@@ -1,6 +1,6 @@
 <?php
 
-class cggm_map extends friendly
+final class cggm_map extends friendly
 {
   private $_map_id;
   private $_name;
@@ -16,53 +16,40 @@ class cggm_map extends friendly
   private $_unsaved_category_template;
   private $_unsaved_dirform_template;
   
-
   public function __construct()
   {
     $this->add_friend('cggm_map_operations,CGGoogleMaps,cggm_map');
-    if( !count(self::$_types) )
-      {
-	$mod = cge_utils::get_module('CGGoogleMaps');
-	$cggm_map_fields = array();
-	include_once(dirname(__FILE__).'/map_fields.dat');
-	if( count($cggm_map_fields) )
-	  {
-	    foreach( $cggm_map_fields as $key => &$rec )
-	      {
-		if( !isset($rec['type']) ) $rec['type'] == 'TEXT';
-		switch($rec['type'])
-		  {
-		  case 'SELECT':
-		    $tmp = cge_array::explode_with_key($rec['options'],'=>',',');
-		    foreach( $tmp as $k => &$v )
-		      {
-			if( startswith($v,'k:') ) 
-			  {
-			    $t2 = substr($v,2);
-			    $v = $mod->Lang($t2);
-			  }
-		      }
-		    $rec['options'] = cge_array::implode_with_key($tmp,'=>',',');
-		    break;
-		  }
+    if( !count(self::$_types) ) {
+      $mod = cge_utils::get_module('CGGoogleMaps');
+      $cggm_map_fields = array();
+      include_once(dirname(__FILE__).'/map_fields.dat');
+      if( count($cggm_map_fields) ) {
+	foreach( $cggm_map_fields as $key => &$rec ) {
+	  if( !isset($rec['type']) ) $rec['type'] == 'TEXT';
+	  switch($rec['type']) {
+	  case 'SELECT':
+	    $tmp = cge_array::explode_with_key($rec['options'],'=>',',');
+	    foreach( $tmp as $k => &$v ) {
+	      if( startswith($v,'k:') ) {
+		$t2 = substr($v,2);
+		$v = $mod->Lang($t2);
 	      }
-	    self::$_types = $cggm_map_fields;
+	    }
+	    $rec['options'] = cge_array::implode_with_key($tmp,'=>',',');
+	    break;
 	  }
+	}
+	self::$_types = $cggm_map_fields;
       }
+    }
 
-    if( count(self::$_types) )
-      {
-	// sets some defaults for the member variables.
-	foreach( self::$_types as $prop => $info )
-	  {
-	    if( $prop == 'id' || $prop == 'map_id' ) continue; // no default for you.
-
-	    if( isset($info['dflt']) )
-	      {
-		$this->$prop = $info['dflt'];
-	      }
-	  }
+    if( count(self::$_types) ) {
+      // sets some defaults for the member variables.
+      foreach( self::$_types as $prop => $info ) {
+	if( $prop == 'id' || $prop == 'map_id' ) continue; // no default for you.
+	if( isset($info['dflt']) ) $this->$prop = $info['dflt'];
       }
+    }
   }
 
 
@@ -142,62 +129,55 @@ class cggm_map extends friendly
 
   public function __get($key)
   {
-    switch( $key )
-      {
-      case 'name':
-	return $this->_name;
-      case 'id':
-	return $this->_map_id;
-      case 'owner_id':
-	return $this->_owner_id;
-      default:
-	if( in_array($key,array_keys(self::$_types)) )
-	  {
-	    if( isset($this->_data[$key]) )
-	      {
-		return $this->_data[$key];
-	      }
-	    else
-	      return;
-	  }
+    switch( $key ) {
+    case 'name':
+      return $this->_name;
+    case 'id':
+      return $this->_map_id;
+    case 'owner_id':
+      return $this->_owner_id;
+    default:
+      if( in_array($key,array_keys(self::$_types)) ) {
+	if( isset($this->_data[$key]) ) {
+	  return $this->_data[$key];
+	}
+	else {
+	  return;
+	}
 
 	$trace = debug_backtrace();
         trigger_error('Undefined property via __get(): '.$key.' in '.$trace[0]['file'].' on line ' . $trace[0]['line'], E_USER_NOTICE);
-	
       }
+      break;
+    }
   }
 
 
   public function __set($key,$value)
   {
-    switch( $key )
-      {
-      case 'name':
-	return $this->set_name($value);
-      case 'id':
-	return $this->set_id($value);
-      case 'owner_id':
-	return $this->set_owner_id($value);
-      default:
-	if( in_array($key,array_keys(self::$_types)) )
-	  {
-	    // todo: type checking.
-	    $this->_data[$key] = $value;
-	    return;
-	  }
-
-	$trace = debug_backtrace();
-	throw new Exception('Undefined property via __set(): '.$key.' in '.$trace[0]['file'].' on line '.$trace[1]['line']);
+    switch( $key ) {
+    case 'name':
+      return $this->set_name($value);
+    case 'id':
+      return $this->set_id($value);
+    case 'owner_id':
+      return $this->set_owner_id($value);
+    default:
+      if( in_array($key,array_keys(self::$_types)) ) {
+	// todo: type checking.
+	$this->_data[$key] = $value;
+	return;
       }
+
+      $trace = debug_backtrace();
+      throw new Exception('Undefined property via __set(): '.$key.' in '.$trace[0]['file'].' on line '.$trace[1]['line']);
+    }
   }
 
 
   public function save($deep = false)
   {
-    if( empty($this->_map_id) )
-      {
-	return cggm_map_operations::insert($this,$deep);
-      }
+    if( empty($this->_map_id) )	return cggm_map_operations::insert($this,$deep);
 
     return cggm_map_operations::update($this,$deep);
   }
@@ -205,9 +185,7 @@ class cggm_map extends friendly
 
   public function add_kml($href)
   {
-    if( !is_array($this->_kml_files) ) {
-      $this->_kml_files = array();
-    }
+    if( !is_array($this->_kml_files) ) $this->_kml_files = array();
 
     $this->_kml_files[] = $href;
   }
@@ -215,9 +193,7 @@ class cggm_map extends friendly
 
   public function get_kml_files()
   {
-    if( !is_array($this->_kml_files) || count($this->_kml_files) == 0 ) {
-      return;
-    }
+    if( !is_array($this->_kml_files) || count($this->_kml_files) == 0 ) return;
 
     return $this->_kml_files;
   }
@@ -230,22 +206,20 @@ class cggm_map extends friendly
     $name = str_replace('-','_',$name);
     $tmp = '';
     $n = 0;
-    while( $n < 10 )
-      {
-	$tmp = str_replace('__','_',$name);
-	if( $tmp == $name ) break;
-	$name = $tmp;
-	$n++;
-      }
+    while( $n < 10 ) {
+      $tmp = str_replace('__','_',$name);
+      if( $tmp == $name ) break;
+      $name = $tmp;
+      $n++;
+    }
 
     // generate an unused name.
     $n = 1;
     $tmp = $name;
-    while( isset($this->_markers[$tmp]) && $n < 100 )
-      {
-	$n++;
-	$tmp = $name.'_'.$n;
-      }
+    while( isset($this->_markers[$tmp]) && $n < 100 ) {
+      $n++;
+      $tmp = $name.'_'.$n;
+    }
     $name = $tmp;
 
     if( $n == 100 ) return FALSE;
@@ -255,10 +229,7 @@ class cggm_map extends friendly
 
   public function add_marker(cggm_marker& $marker)
   {
-    if( !is_array($this->_markers) )
-      {
-	$this->_markers = array();
-      }
+    if( !is_array($this->_markers) ) $this->_markers = array();
 
     $name = $this->generate_marker_name($marker->get_title());
     if( !$name ) return FALSE;
@@ -283,21 +254,16 @@ class cggm_map extends friendly
     if( $idx >= count($this->_markers) || $idx < 0 ) return;
 
     $tmp = $trace = debug_backtrace();
-    if(isset($trace[1]['class']) && $trace[1]['class'] == 'cggm_map_operations')
-      {
-	return $this->_markers[$idx];
-      }
+    if(isset($trace[1]['class']) && $trace[1]['class'] == 'cggm_map_operations') return $this->_markers[$idx];
   }
 
 
   public function get_marker_by_id($marker_id)
   {
     if( !is_array($this->_markers) ) return FALSE;
-    foreach( $this->_markers as $name => $marker )
-      {
-	if( $marker->get_marker_id() == $marker_id )
-	  return $marker;
-      }
+    foreach( $this->_markers as $name => $marker ) {
+      if( $marker->get_marker_id() == $marker_id ) return $marker;
+    }
     return FALSE;
   }
 
@@ -332,21 +298,16 @@ class cggm_map extends friendly
   public function get_map_template($unsaved = false)
   {
     $mod = cge_utils::get_module('CGGoogleMaps');
-    if( $this->_unsaved_map_template )
-      {
-	return $this->_unsaved_map_template;
-      }
+    if( $this->_unsaved_map_template ) return $this->_unsaved_map_template;
 
     if( $unsaved ) return;
-    if( $this->_map_id )
-      {
-        $txt = $mod->GetTemplate($this->get_map_template_name());
-	return $txt;
-      }
-    else
-      {
-	return $mod->GetTemplate(CGGM_PREF_NEWMAP_TEMPLATE);
-      }
+    if( $this->_map_id ) {
+      $txt = $mod->GetTemplate($this->get_map_template_name());
+      return $txt;
+    }
+    else {
+      return $mod->GetTemplate(CGGM_PREF_NEWMAP_TEMPLATE);
+    }
   }
 
 
@@ -366,21 +327,16 @@ class cggm_map extends friendly
   public function get_baloon_template($unsaved = false)
   {
     $mod = cge_utils::get_module('CGGoogleMaps');
-    if( $this->_unsaved_baloon_template )
-      {
-	return $this->_unsaved_baloon_template;
-      }
+    if( $this->_unsaved_baloon_template ) return $this->_unsaved_baloon_template;
 
     if( $unsaved ) return;
-    if( $this->_map_id )
-      {
-        $txt = $mod->GetTemplate($this->get_baloon_template_name());
-	return $txt;
-      }
-    else
-      {
-	return $mod->GetTemplate(CGGM_PREF_NEWBALOON_TEMPLATE);
-      }
+    if( $this->_map_id ) {
+      $txt = $mod->GetTemplate($this->get_baloon_template_name());
+      return $txt;
+    }
+    else {
+      return $mod->GetTemplate(CGGM_PREF_NEWBALOON_TEMPLATE);
+    }
   }
 
 
@@ -392,27 +348,21 @@ class cggm_map extends friendly
 
   public function get_js_template_name()
   {
-    if( $this->_map_id )
-      return 'mapjs_'.$this->_map_id;
+    if( $this->_map_id ) return 'mapjs_'.$this->_map_id;
   }
 
 
   public function get_js_template($unsaved = false)
   {
-    if( $this->_unsaved_js_template )
-      {
-	return $this->_unsaved_js_template;
-      }
+    if( $this->_unsaved_js_template ) return $this->_unsaved_js_template;
     if( $unsaved ) return;
     $mod = cge_utils::get_module('CGGoogleMaps');
-    if( $this->_map_id )
-      {
-	return $mod->GetTemplate($this->get_js_template_name());
-      }
-    else
-      {
-	return $mod->GetTemplate(CGGM_NEWJS_TEMPLATE);
-      }
+    if( $this->_map_id ) {
+      return $mod->GetTemplate($this->get_js_template_name());
+    }
+    else {
+      return $mod->GetTemplate(CGGM_NEWJS_TEMPLATE);
+    }
   }
 
 
@@ -424,27 +374,21 @@ class cggm_map extends friendly
 
   public function get_sidebar_template_name()
   {
-    if( $this->_map_id )
-      return 'mapsidebar_'.$this->_map_id;
+    if( $this->_map_id ) return 'mapsidebar_'.$this->_map_id;
   }
 
 
   public function get_sidebar_template($unsaved = false)
   {
-    if( $this->_unsaved_sidebar_template )
-      {
-	return $this->_unsaved_sidebar_template;
-      }
+    if( $this->_unsaved_sidebar_template ) return $this->_unsaved_sidebar_template;
     if( $unsaved ) return;
     $mod = cge_utils::get_module('CGGoogleMaps');
-    if( $this->_map_id )
-      {
-	return $mod->GetTemplate($this->get_sidebar_template_name());
-      }
-    else
-      {
-	return $mod->GetTemplate(CGGM_NEWSIDEBAR_TEMPLATE);
-      }
+    if( $this->_map_id ) {
+      return $mod->GetTemplate($this->get_sidebar_template_name());
+    }
+    else {
+      return $mod->GetTemplate(CGGM_NEWSIDEBAR_TEMPLATE);
+    }
   }
 
 
@@ -462,21 +406,16 @@ class cggm_map extends friendly
 
   public function get_category_template($unsaved = false)
   {
-    if( $this->_unsaved_category_template )
-      {
-	return $this->_unsaved_category_template;
-      }
+    if( $this->_unsaved_category_template ) return $this->_unsaved_category_template;
 
     if( $unsaved ) return;
     $mod = cge_utils::get_module('CGGoogleMaps');
-    if( $this->_map_id )
-      {
-	return $mod->GetTemplate($this->get_category_template_name());
-      }
-    else
-      {
-	return $mod->GetTemplate(CGGM_NEWCATEGORY_TEMPLATE);
-      }
+    if( $this->_map_id ) {
+      return $mod->GetTemplate($this->get_category_template_name());
+    }
+    else {
+      return $mod->GetTemplate(CGGM_NEWCATEGORY_TEMPLATE);
+    }
   }
 
 
@@ -494,21 +433,16 @@ class cggm_map extends friendly
 
   public function get_dirform_template($unsaved = false)
   {
-    if( $this->_unsaved_dirform_template )
-      {
-	return $this->_unsaved_dirform_template;
-      }
+    if( $this->_unsaved_dirform_template ) return $this->_unsaved_dirform_template;
 
     if( $unsaved ) return;
     $mod = cge_utils::get_module('CGGoogleMaps');
-    if( $this->_map_id )
-      {
-	return $mod->GetTemplate($this->get_dirform_template_name());
-      }
-    else
-      {
-	return $mod->GetTemplate(CGGM_NEWDIRFORM_TEMPLATE);
-      }
+    if( $this->_map_id ) {
+      return $mod->GetTemplate($this->get_dirform_template_name());
+    }
+    else {
+      return $mod->GetTemplate(CGGM_NEWDIRFORM_TEMPLATE);
+    }
   }
 
 
